#[repr(C)]pub struct DroppedRecordStats {
pub first_dropped: InstantBootTicks,
pub last_dropped: InstantBootTicks,
pub num_dropped: u32,
pub bytes_dropped: u32,
pub has_dropped: bool,
}Expand description
This struct keeps track of the duration, number, and size of trace records dropped when the buffer is full. These statistics are emitted to the trace buffer as a duration as soon as space is available to do so, at which point the values are reset to 0, or false in the case of has_dropped.
Fields
first_dropped: InstantBootTickslast_dropped: InstantBootTicksnum_dropped: u32By storing num_dropped and bytes_dropped in 32-bit values, we ensure that they can each be stored in a single 64-bit word in the FXT record we emit when space is available.
bytes_dropped: u32has_dropped: boolImplementations
Sourceimpl DroppedRecordStats
impl DroppedRecordStats
pub fn reset(&mut self)
pub fn track(&mut self, now: InstantBootTicks, size: u32)
pub fn has_dropped(&self) -> bool